@@ -1,12 +1,16 @@
 loadKarsTSFonts <-
 function() {
+  
     fontmainbt <- tcltk::tkfont.create(family = "Arial", 
                                        size = 14, weight = "bold")
     fontsubbt <- tcltk::tkfont.create(family = "Arial", 
                                       size = 12, weight = "bold")
+    fontsubbt1 <- tcltk::tkfont.create(family = "Arial", 
+                                      size = 12, weight = "bold",
+                                      underline = TRUE)
     fonttitle0pan <- tcltk::tkfont.create(family = "Arial", 
                                           size = 11, weight = "bold", 
-        underline = TRUE)
+                                          underline = TRUE)
     fonttitle1pan <- tcltk::tkfont.create(family = "Arial", 
                                           size = 11, weight = "bold")
     fonttitle2pan <- tcltk::tkfont.create(family = "Arial", 
@@ -14,10 +18,10 @@ function() {
     fontnormpan <- tcltk::tkfont.create(family = "Arial", size = 11)
     fontaclara <- tcltk::tkfont.create(family = "Arial", 
                                        size = 11, slant = "italic")
-    KarsTSFonts <- list(mainBt = fontmainbt, subBt = fontsubbt, 
-                        explain = fontaclara, T0 = fonttitle0pan, 
-                        T1 = fonttitle1pan, T2 = fonttitle2pan, 
-                        normal = fontnormpan)
-    assign("KTSFonts", KarsTSFonts, envir = KTSEnv)
-    
+    KTSEnv$KTSFonts <- list(mainBt = fontmainbt, subBt = fontsubbt,
+                            subBt1 = fontsubbt1,
+                            explain = fontaclara, T0 = fonttitle0pan, 
+                            T1 = fonttitle1pan, T2 = fonttitle2pan, 
+                            normal = fontnormpan)
+ 
 }
